# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\u1021',
            '\u1021\u102C',
            '\u1023',
            'ဣဳ',
            '\u1025',
            'ဥူ',
            '\u1052',
            '\u1053',
            '\u1054',
            '\u1055',
            'ဨ',
            '\u1021\u1032',
            '\u1029',
            '\u102A',
            ]

SouthVowelMap = [
                'ဨ\u02BD',
                '\u1029\u02BD',
                ]

ModernVowelMap = [
                 'ဨ\u02BD',
                 '\u1021\u102C\u02BD',
                 ]

SinhalaVowelMap = [
                  'ဨ\u02BD'
                  ]

VowelSignMap =  [
                '\u102C',
                '\u102D',
                'ဳ',
                '\u102F',
                '\u1030',
                '\u1056',
                '\u1057',
                '\u1058',
                '\u1059',
                '\u1031',
                '\u1032',
                '\u1031\u102C',
                '\u1031\u102C\u103A',
                ]

SouthVowelSignMap = [
                    '\u1031\u02BD',
                    '\u1031\u102C\u02BD',
                    ]

ModernVowelSignMap =[
                    '\u1031\u02BD',
                    '\u102C\u02BD']

SinhalaVowelSignMap = [
                      '\u1031\u02BD'
                      ]

AyogavahaMap = [
               '\u1036\u02BD',
               '\u1036',
               '\u1038'
               ]

ViramaMap =  [
             '\u103A'
             ]

ConsonantMap =  [
                '\u1000',
                '\u1001',
                '\u1002',
                '\u1003',
                'ၚ',

                '\u1005',
                '\u1006',
                '\u1007',
                'ၛ',
                'ည',

                '\u100B',
                '\u100C',
                '\u100D',
                '\u100E',
                '\u100F',

                '\u1010',
                '\u1011',
                '\u1012',
                '\u1013',
                '\u1014',

                '\u1015',
                '\u1016',
                '\u1017',
                '\u1018',
                '\u1019',

                '\u101A',
                '\u101B',
                '\u101C',
                '\u101D',

                '\u1050',
                '\u1051',
                '\u101E',
                '\u101F'
                ]

SouthConsonantMap = [
                    '\u1020',
                    '\u1020\u02BD',
                    '\u101B\u02BD',
                    '\u1014\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\u1000\u02BD',
                     '\u1001\u02BD',
                     '\u1002\u02BD',
                     '\u1007\u02BD',
                     '\u100D\u02BD',
                     '\u100E\u02BD',
                     '\u1016\u02BD',
                     '\u101A\u02BD'
                     ]

SinhalaConsonantMap =[
                     '\u1036\u1002\u02BD',
                     '\u1036\u1007\u02BD',
                     '\u1036\u100D\u02BD',
                     '\u1036\u1012\u02BD',
                     '\u1036\u1017\u02BD',
                      ]

NuktaMap = [
           '\u02BD\u02BD\u02BD\u02BD'
           ]

OmMap = [
        'ဥုံ'
        ]

SignMap =[
         '\u0027',
         '\u104A',
         '\u104B'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']


NumeralMap = [
             '\u1040',
             '\u1041',
             '\u1042',
             '\u1043',
             '\u1044',
             '\u1045',
             '\u1046',
             '\u1047',
             '\u1048',
             '\u1049',
             ]
